aboutsummaryrefslogtreecommitdiffstats
path: root/storage/storer.go
diff options
context:
space:
mode:
Diffstat (limited to 'storage/storer.go')
-rw-r--r--storage/storer.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/storage/storer.go b/storage/storer.go
index 5de0cfb..4800ac7 100644
--- a/storage/storer.go
+++ b/storage/storer.go
@@ -3,14 +3,14 @@ package storage
import (
"errors"
- "gopkg.in/src-d/go-git.v4/config"
- "gopkg.in/src-d/go-git.v4/plumbing/storer"
+ "github.com/go-git/go-git/v5/config"
+ "github.com/go-git/go-git/v5/plumbing/storer"
)
var ErrReferenceHasChanged = errors.New("reference has changed concurrently")
// Storer is a generic storage of objects, references and any information
// related to a particular repository. The package gopkg.in/src-d/go-git.v4/storage
// contains two implementation a filesystem base implementation (such as `.git`)
// and a memory implementations being ephemeral
type Storer interface {
@@ -3,14 +3,14 @@ package storage
var ErrReferenceHasChanged = errors.New("reference has changed concurrently")
// Storer is a generic storage of objects, references and any information
-// related to a particular repository. The package gopkg.in/src-d/go-git.v4/storage
+// related to a particular repository. The package github.com/go-git/go-git/v5/storage
// contains two implementation a filesystem base implementation (such as `.git`)
// and a memory implementations being ephemeral